pub enum ToolError {
NotFound {
name: String,
},
InvalidArguments {
tool: String,
reason: String,
},
ExecutionFailed {
tool: String,
message: String,
},
Timeout {
tool: String,
timeout_ms: u64,
},
Serialization(Error),
AuditFailed(String),
Unavailable {
name: String,
reason: String,
},
}Expand description
Error types for tool execution with precise variants for each failure mode.
Example
use vex_llm::ToolError;
let err = ToolError::not_found("unknown_tool");
assert!(err.to_string().contains("unknown_tool"));Variants
NotFound
Tool not found in registry
InvalidArguments
Invalid arguments provided to tool
ExecutionFailed
Tool execution failed
Timeout
Tool execution exceeded timeout
Serialization(Error)
JSON serialization/deserialization error
AuditFailed(String)
Audit logging failed (non-fatal, logged but doesn’t stop execution)
Tool is disabled or unavailable
Implementations
Sourceimpl ToolError
impl ToolError
Sourcepub fn invalid_args(tool: impl Into<String>, reason: impl Into<String>) -> Self
pub fn invalid_args(tool: impl Into<String>, reason: impl Into<String>) -> Self
Create an InvalidArguments error with context
Security Note
The reason should not contain raw user input to prevent information leakage
Sourcepub fn execution_failed(
tool: impl Into<String>,
message: impl Into<String>,
) -> Self
pub fn execution_failed( tool: impl Into<String>, message: impl Into<String>, ) -> Self
Create an ExecutionFailed error
Security Note
The message should be sanitized before passing to this constructor
Create an Unavailable error
Sourcepub fn is_retryable(&self) -> bool
pub fn is_retryable(&self) -> bool
Check if this error is recoverable (can retry)
Sourcepub fn should_audit(&self) -> bool
pub fn should_audit(&self) -> bool
Check if this error should be logged to audit trail